//
// PovRay scene file for a sci-fi starship drive
//
// Author:   Hj. Malthaner
// Email:    hansjoerg.malthaner@gmx.de
// Date:     2001/06/03
// Update:   2016/03/08
//
// Web:      http://opengameart.org/users/varkalandar
//
// This file is available under the GNU general
// public license v2 or newer.
//
// http://www.gnu.org/licenses/gpl-2.0.html
//


#declare Cam1 = camera 
{
  orthographic
  location < 2.5, 2.5, -2.5 >
  look_at < 0, 0, 0 >
}            


camera 
{ 
  Cam1 
}          


light_source 
{ 
  < 2000, 8000, 500 > 
  color rgb < 1, 1, 1 > 
}


// sky sphere

sphere 
{
  <0,0,0>, 10000

  hollow

  pigment 
  {
    color <0.4, 0.35, 0.3>
  }
}	


#declare TEX_METAL = 
texture 
{
  pigment 
  {
    color <0.8, 0.8, 1.0>
  }

  normal
  {
    bozo 0.1
    scale 0.5
  }

  finish 
  {
    ambient 0.1
    brilliance 6
    diffuse 0.7
    metallic
    specular 0.80
    roughness 1/120
    reflection 0.6
  }
}


#declare SIDEPART = 
union 
{
  sphere 
  {
    <0, 0, 0>, 1.0
    scale <1.0, 0.5, 1.0>
    translate <0, 0, 1>
  }	

  cylinder 
  {
    <0, 0, 0>, 
    <0, 0, 1>, 1.0
    scale <1.0, 0.5, 1.0>
    translate <0, 0, 1>
  }

  texture 
  {
    TEX_METAL
    pigment 
    {
      color <0.7, 1.0, 0.8>
    }
  }
}


#declare PIPE = 
union 
{
  sphere 
  {
    <0, 0, 0>, 1.0
  }	

  cylinder 
  {
    <0, 0, 0>, 
    <0, -3, 0>, 1.0
  }

  cylinder 
  {
    <0, 0, 0>, 
    <-3, 0, 0>, 1.0
  }

  texture 
  {
    TEX_METAL
  }
}


#declare PIPES_L = 
union 
{
  object 
  {
    PIPE
    rotate <0,15,0>
    scale 0.15
    translate <+0.0, 0.0, -0.6>
  }

  object 
  {
    PIPE
    rotate <0,10,0>
    scale 0.15
    translate <+0.07, 0.0, -0.3>
  }

  object 
  {
    PIPE
    rotate <0,5,0>
    scale 0.15
    translate <+0.09, 0.0, 0.0>
  }

  object 
  {
    PIPE
    scale 0.15
    translate <+0.1, 0.0, 0.3>
  }
}


#declare PIPES_R = 
union 
{
  object 
  {
    PIPE
    rotate <0,165,0>
    scale 0.15
    translate <-0.0, 0.0, -0.6>
  }

  object 
  {
    PIPE
    rotate <0,170,0>
    scale 0.15
    translate <-0.07, 0.0, -0.3>
  }

  object 
  {
    PIPE
    rotate <0,175,0>
    scale 0.15
    translate <-0.09, 0.0, 0.0>
  }

  object 
  {
    PIPE
    rotate <0,180,0>
    scale 0.15
    translate <-0.1, 0.0, 0.3>
  }
}


#declare FLOOR = 
box 
{
  <-1.5, -0.30, -1>,
  <1.5, -0.6, 2>

  texture 
  {
    pigment 
    {
      color <0.8, 0.8, 0.8>
    }

    finish 
    {
      ambient 0.1
      brilliance 2
      diffuse 0.8
      metallic
      specular 0.10
      roughness 1/120
      reflection 0.1
    }
  }
}


#declare CORE = 
union 
{
  sphere 
  {
    <0, 0, 0>, 1.0
    scale <1.0, 0.5, 1.0>
  }	

  sphere 
  {
    <0, 0, 0>, 1.0
    scale <1.0, 0.5, 1.0>
    translate <0, 0, 1>
  }	

  cylinder 
  {
    <0, 0, 0>, 
    <0, 0, 1>, 1.0
    scale <1.0, 0.5, 1.0>
    translate <0, 0, 0.99999>
  }

  texture 
  {
    TEX_METAL

    pigment { color rgb <0.9, 0.9, 0.7> }
		
    normal 
    {
      agate 0.05
      scale <0.05, 0.05, 0.5>
    }        
  }
}


#declare O_DRIVE=
union 
{
  object 
  {
    CORE
  }

  object 
  {
    SIDEPART
    scale <0.4, 0.9, 0.7>
    translate <-1, -0.2, 0.599999>
  }

  object 
  {
    SIDEPART
    scale <0.4, 0.9, 0.7>
    translate <+1, -0.2, 0.599999>
  }

  object 
  {
    PIPES_L
    translate <+1.0, 0.0, 0.0>
  }

  object 
  {
    PIPES_R
    translate <-1.0, 0.0, 0.0>
  }

  object 
  {
    FLOOR
  }

  scale 0.45
}

union
{
  object
  {
    O_DRIVE
    translate <0, 0, -2>
    rotate <0, 0, 0>
  }
  object
  {
    O_DRIVE
    translate <0, 0, -2>
    rotate <0, 90, 0>
  }
  object
  {
    O_DRIVE
    translate <0, 0, -2>
    rotate <0, 180, 0>
  }
  object
  {
    O_DRIVE
    translate <0, 0, -2>
    rotate <0, 270, 0>
  }
}
